QueryObject

Trait QueryObject 

pub trait QueryObject: JmapObject {
    type Filter: Serialize + DeserializeOwned + Send + Sync + 'static;
    type Comparator: Serialize + DeserializeOwned + Send + Sync + 'static;
}
Marker for object types that support query and queryChanges operations.

Required Associated Types

type Filter: Serialize + DeserializeOwned + Send + Sync + 'static

The filter condition type.

Must implement both Serialize and DeserializeOwned so that backends can inspect or forward the filter.

type Comparator: Serialize + DeserializeOwned + Send + Sync + 'static

The comparator type for sort operations.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors