Module resultref

Module resultref 

RFC 8620 7 ResultReference — back-references between method calls in a batch.

Provides ResultReference and Argument<T>.

Structs

ResultReference
A reference to the result of a previous invocation in the same JMAP request batch. Used in method arguments with a “#” prefix on the JSON key (RFC 8620 9).

Enums

Argument
A JMAP method argument that can be either a direct value or a ResultReference.